#!/bin/sh

for x in /dev/md* ; do
	mdadm --stop $x
done

for disk in $(list-harddrives | grep -v fd0 | awk '{printf $1 " "}'); do
	{ echo ${disk} | grep -q "nvme"; } && wipefs -a -f /dev/${disk}p[0-9] || wipefs -a -f /dev/${disk}[0-9]
	wipefs -a -f /dev/${disk}
	mdadm --zero-superblock /dev/${disk}
	dd if=/dev/zero of=/dev/$disk bs=512 count=32
	blkdiscard --secure /dev/${disk}
	parted -s /dev/${disk} mklabel gpt;
	partprobe
done

for x in /dev/md* ; do
	mdadm --stop $x
done

SWSIZE=$(grep MemTotal /proc/meminfo  | awk '{print int($2/1024)+1}')
if [ ${SWSIZE} -gt 2048 ]; then
	SWSIZE=2048
fi

set $(list-harddrives | grep -v fd0 | grep -v md[0-9] | awk '{printf $1 " "}')
HD1=$1
HD2=$2
HD3=$3
HD4=$4

echo "clearpart --all --initlabel --disklabel=gpt" >> /tmp/part-include

if [ -d /sys/firmware/efi ]; then
	efibootmgr -v | grep BootCurrent | cut -d' ' -f2 > /tmp/efi_booted
	cat >> /tmp/part-include <<- EOF
	part raid.11 --size=350 --asprimary --ondisk=${HD1}
	part raid.21 --size=350 --asprimary --ondisk=${HD2}
	part raid.31 --size=350 --asprimary --ondisk=${HD3}
	part raid.41 --size=350 --asprimary --ondisk=${HD4}
	raid /boot/efi --fstype efi --level=RAID1 --device=md0 raid.11 raid.21 raid.31 raid.41
	EOF
else
	cat >> /tmp/part-include <<- EOF
	part biosboot --fstype=biosboot --size=2 --asprimary --ondisk=${HD1}
	part biosboot --fstype=biosboot --size=2 --asprimary --ondisk=${HD2}
	part biosboot --fstype=biosboot --size=2 --asprimary --ondisk=${HD3}
	part biosboot --fstype=biosboot --size=2 --asprimary --ondisk=${HD4}
	part raid.11 --size=512 --asprimary --ondisk=${HD1}
	part raid.21 --size=512 --asprimary --ondisk=${HD2}
	part raid.31 --size=512 --asprimary --ondisk=${HD1}
	part raid.41 --size=512 --asprimary --ondisk=${HD2}
	raid /boot --fstype ext4 --level=RAID1 --device=md0 raid.11 raid.21 raid.31 raid.41
	EOF
fi
cat >> /tmp/part-include <<- EOF
part raid.12 --size=${SWSIZE} --ondisk=${HD1}
part raid.22 --size=${SWSIZE} --ondisk=${HD2}
part raid.32 --size=${SWSIZE} --ondisk=${HD3}
part raid.42 --size=${SWSIZE} --ondisk=${HD4}
part raid.13 --size=1 --grow --ondisk=${HD1}
part raid.23 --size=1 --grow --ondisk=${HD2}
part raid.33 --size=1 --grow --ondisk=${HD3}
part raid.43 --size=1 --grow --ondisk=${HD4}
raid swap --fstype swap --level=RAID10 --device=md1 raid.12 raid.22 raid.32 raid.42
raid / --fstype xfs --mkfsoptions=-K --level=RAID10 --device=md2 raid.13 raid.23 raid.33 raid.43
bootloader --location=mbr --boot-drive=${HD1} --driveorder=${HD1},${HD2},${HD3},${HD4} --append="consoleblank=0"
EOF
